/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;



    /// <summary> The simplest type of mapping to a database column. The
    /// <c>Basic</c> annotation can be applied to a persistent
    /// property or instance variable of any of the following types:
    ///<para>
    /// primitive types, wrappers of the primitive types, <c>String</c>, 
    /// </para>
    ///<para>
    /// <c>System.Numerics.BigInteger</c>,
    /// </para>
    ///<para>
    /// <c>System.Decimal</c>,
    /// </para>
    ///<para>
    /// <c>System.DateTime</c>,
    /// </para>
    ///<para>
    /// <c>System.Data.DbType.Date</c>, 
    /// </para>
    ///<para>
    /// <c>System.Data.DbType.Time</c>,
    /// </para>
    ///<para>
    /// <c>System.Data.DbType.Timestamp</c>, <c>byte[]</c>, <c>Byte[]</c>,
    /// </para>
    ///<para>
    /// <c>char[]</c>, <c>Character[]</c>, enums, and any other type that
    /// implements <c>System.Runtime.Serialization.ISerializable</c>.
    /// </para>
    ///<para>
    ///  The use of the <c>Basic</c> annotation is optional for
    /// persistent fields and properties of these types.  If the
    /// <c>Basic</c> annotation is not specified for such a field or
    /// property, the default values of the <c>Basic</c> annotation
    /// will apply.
    /// </para>
    /// <example><code>
    ///    Example 1:
    /// 
    ///    &#91;Basic&#93;
    ///    protected String name;
    /// 
    ///    Example 2:
    /// 
    ///    &#91;Basic(fetch=LAZY)&#93;
    ///    protected String getName() { return name; }
    /// 
    /// </code></example>
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)] 

public sealed class Basic : System.Attribute {

    /// <summary> (Optional) Defines whether the value of the field or property should 
    /// be lazily loaded or must be eagerly fetched. The <c>EAGER</c> 
    /// strategy is a requirement on the persistence provider runtime 
    /// that the value must be eagerly fetched.  The <c>LAZY</c> 
    /// strategy is a hint to the persistence provider runtime.
    /// If not specified, defaults to <c>EAGER</c>.
    /// </summary>
    public FetchType Fetch = FetchType.EAGER;

    /// <summary> (Optional) Defines whether the value of the field or property may be null. 
    /// This is a hint and is disregarded for primitive types; it may 
    /// be used in schema generation.
    /// If not specified, defaults to <c>true</c>.
    /// </summary>
    public bool Optional = true;
}
}