/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Specifies the value of the discriminator column for 
    /// entities of the given type. 
    ///<para>
    ///  The <c>DiscriminatorValue</c> 
    /// annotation can only be specified on a concrete entity 
    /// class. 
    /// </para>
    ///<para>
    ///  If the <c>DiscriminatorValue</c> annotation is not 
    /// specified and a discriminator column is used, a provider-specific 
    /// function will be used to generate a value representing the 
    /// entity type.  If the <see cref="DiscriminatorType"/> is <c>
    /// STRING</c>, the discriminator value 
    /// default is the entity name. 
    /// </para>
    ///<para>
    ///  The inheritance strategy and the discriminator column 
    /// are only specified in the root of an entity class hierarchy 
    /// or subhierarchy in which a different inheritance strategy is 
    /// applied. The discriminator value, if not defaulted, should be 
    /// specified for each entity class in the hierarchy.
    /// </para>
    /// <example><code>
    /// 
    ///    Example:
    /// 
    ///    &#91;Entity&#93;
    ///    &#91;Table(name="CUST")&#93;
    ///    &#91;Inheritance(strategy=SINGLE_TABLE)&#93;
    ///    &#91;DiscriminatorColumn(name="DISC", discriminatorType=STRING, length=20)&#93;
    ///    &#91;DiscriminatorValue("CUSTOMER")&#93;
    ///    public class Customer { ... }
    /// 
    ///    &#91;Entity&#93;
    ///    &#91;DiscriminatorValue("VCUSTOMER")&#93;
    ///    public class ValuedCustomer extends Customer { ... }
    /// </code></example>
    /// 
    /// <seealso cref="DiscriminatorColumn"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class)] 


public sealed class DiscriminatorValue : System.Attribute {

    /// <summary> (Optional) The value that indicates that the
    /// row is an entity of the annotated entity type.
    /// 
    ///  If the <c>DiscriminatorValue</c> annotation is not
    /// specified and a discriminator column is used, a
    /// provider-specific function will be used to generate a value
    /// representing the entity type.  If the <c>DiscriminatorType</c> is
    /// <c>STRING</c>, the discriminator value default is the
    /// entity name.
    /// </summary>
    public string Value; 
        public DiscriminatorValue() {} 
        public DiscriminatorValue(string value) { Value = value; } 
}
}