/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;



    /// <summary> Defines a collection of instances of a basic type or embeddable
    /// class. 
    /// Must be specified if the collection is to be mapped by
    /// means of a collection table.
    /// 
    /// <example><code>
    ///    Example:
    /// 
    ///    &#91;Entity&#93; public class Person {
    ///       &#91;Id&#93; protected String ssn;
    ///       protected String name;
    ///       ...
    ///       &#91;ElementCollection&#93;  
    ///       protected Set&#060;String&#062; nickNames = new HashSet();
    ///         ...
    ///    } 
    /// </code> </example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)]/*@Target( { METHOD, FIELD })*/

public sealed class ElementCollection : System.Attribute {

    /// <summary> (Optional) The basic or embeddable class that is the element
    /// type of the collection.  This element is optional only if the
    /// collection field or property is defined using generics,
    /// and must be specified otherwise.  It defaults to the
    /// paramterized type of the collection when defined using
    /// generics.
    /// </summary>
    public System.Type TargetClass = typeof(void);
    
    /// <summary>  (Optional) Whether the collection should be lazily loaded or must be
    ///  eagerly fetched.  The EAGER strategy is a requirement on
    ///  the persistence provider runtime that the collection elements
    ///  must be eagerly fetched.  The LAZY strategy is a hint to the
    ///  persistence provider runtime.
    /// </summary>
    public FetchType Fetch = FetchType.LAZY;
}
}