/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Defines a class whose instances are stored as an intrinsic 
    /// part of an owning entity and share the identity of the entity. 
    /// Each of the persistent properties or fields of the embedded 
    /// object is mapped to the database table for the entity. 
    /// 
    ///<para>
    ///  Note that the <see cref="Transient"/> annotation may be used to 
    /// designate the non-persistent state of an embeddable class.
    /// </para>
    /// <example><code>
    /// 
    ///    Example 1:
    /// 
    ///    &#91;Embeddable&#93; public class EmploymentPeriod { 
    ///       &#91;Temporal(DATE)&#93; System.DateTime startDate;
    ///       &#91;Temporal(DATE)&#93; System.DateTime endDate;
    ///      ... 
    ///    }
    /// 
    ///    Example 2:
    /// 
    ///    &#91;Embeddable&#93; public class PhoneNumber {
    ///        protected String areaCode;
    ///        protected String localNumber;
    ///        &#91;ManyToOne&#93; PhoneServiceProvider provider;
    ///        ...
    ///     }
    /// 
    ///    &#91;Entity&#93; public class PhoneServiceProvider {
    ///        &#91;Id&#93; protected String name;
    ///         ...
    ///     }
    /// 
    ///    Example 3:
    /// 
    ///    &#91;Embeddable&#93; public class Address {
    ///       protected String street;
    ///       protected String city;
    ///       protected String state;
    ///       &#91;Embedded&#93; protected Zipcode zipcode;
    ///    }
    /// 
    ///    &#91;Embeddable&#93; public class Zipcode {
    ///       protected String zip;
    ///       protected String plusFour;
    ///     }
    /// </code></example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class)]/*@Documented*/
 

public sealed class Embeddable : System.Attribute {
}
}