/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> Applied to a persistent field or property of an entity 
    /// class or mapped superclass to denote a composite primary 
    /// key that is an embeddable class. The embeddable class 
    /// must be annotated as <see cref="Embeddable"/>. 
    ///<para>
    ///  There must be only one <c>EmbeddedId</c> annotation and
    /// no <c>Id</c> annotation when the <c>EmbeddedId</c> annotation is used.
    /// </para>
    ///<para>
    ///  The <see cref="AttributeOverride"/> annotation may be used to override
    /// the column mappings declared within the embeddable class.
    /// </para>
    ///<para>
    ///  The <see cref="MapsId"/> annotation may be used in conjunction
    /// with the <c>EmbeddedId</c> annotation to specify a derived
    /// primary key.
    /// </para>
    ///<para>
    ///  If the entity has a derived primary key, the
    /// <c>AttributeOverride</c> annotation may only be used to
    /// override those attributes of the embedded id that do not correspond
    /// to the relationship to the parent entity.
    /// </para>
    ///<para>
    ///  Relationship mappings defined within an embedded id class are not supported.
    /// </para>
    /// <example><code>
    ///    Example 1:
    /// 
    ///    &#91;Embedded&#93;Id
    ///    protected EmployeePK empPK;
    /// 
    /// 
    ///    Example 2:
    /// 
    ///    &#91;Embeddable&#93;
    ///    public class DependentId {
    ///       String name;
    ///       EmployeeId empPK;   // corresponds to primary key type of Employee
    ///    }
    /// 
    ///    &#91;Entity&#93;
    ///    public class Dependent {
    ///       // default column name for "name" attribute is overridden
    ///       &#91;AttributeOverride(PropertyName="name", Name="dep_name")&#93;
    ///       &#91;Embedded&#93;Id DependentId id;
    ///       ...
    ///       &#91;MapsId("empPK")&#93;
    ///       &#91;ManyToOne&#93; Employee emp;
    ///    }
    /// </code></example>
    /// 
    /// <seealso cref="Embeddable"/>
    /// <seealso cref="MapsId"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)]


public sealed class EmbeddedId : System.Attribute {}
}