/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Thrown by the persistence provider when <see cref="EntityManager.Persist(Object)"/> is called
/// and the entity already exists. The
/// current transaction, if one is active, will be marked for rollback.
    ///<para>
/// If the entity already exists, the <c>EntityExistsException</c> may be thrown when
/// the persist operation is invoked, or the <c>EntityExistsException</c> or another
/// <c>PersistenceException</c> may be thrown at flush or commit time.
///  The current transaction, if one is active, will be marked for rollback.
    /// </para>
/// <seealso cref="M:NPersistence.EntityManager.Persist(Object)"/>
/// 
/// 
/// </summary>
public class EntityExistsException : PersistenceException {

    /// <summary> Constructs a new <c>EntityExistsException</c> exception with
    /// <c>null</c> as its detail message.
    /// </summary>
    public EntityExistsException() : base() {
        // super(...) -> base(...)
    }

    /// <summary> Constructs a new <c>EntityExistsException</c> exception with the
    /// specified detail message.
    /// 
    /// </summary>
    /// <param name="message">
    ///            the detail message.</param>
    
    public EntityExistsException(string message) : base(message) {
        // super(...) -> base(...)
    }

    /// <summary> Constructs a new <c>EntityExistsException</c> exception with the
    /// specified detail message and cause.
    /// 
    /// </summary>
    /// <param name="message">
    ///            the detail message.</param>
    /// <param name="cause">
    ///            the cause.</param>
    
    public EntityExistsException(string message, System.Exception cause) : base(message, cause) {
        // super(...) -> base(...)
    }

    /// <summary> Constructs a new <c>EntityExistsException</c> exception with the
    /// specified cause.
    /// 
    /// <param name="cause">
    ///            the cause.</param>
    /// </summary>
    public EntityExistsException(System.Exception cause) : base(cause) {
        // super(...) -> base(...)
    }
}
}