/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


/// <summary> Used in the mapping of associations. It is specified on the
/// owning side of an association.  
    /// <para>
///  A join table is typically used in the mapping of many-to-many
/// and unidirectional one-to-many associations. It may also be used to
/// map bidirectional many-to-one/one-to-many associations,
/// unidirectional many-to-one relationships, and one-to-one
/// associations (both bidirectional and unidirectional).
    /// </para>
    /// <para>
/// When a join table is used in mapping a relationship with an
/// embeddable class on the owning side of the relationship, the
/// containing entity rather than the embeddable class is considered the
/// owner of the relationship.
    /// </para>
    /// <para>
///  If the <c>JoinTable</c> annotation is missing, the 
/// default values of the annotation elements apply.  
/// The name of the join table is assumed to be the table names of the 
/// associated primary tables concatenated together (owning side 
/// first) using an underscore.
/// </para>
/// <example><code>
/// 
///    Example:
/// 
///    &#91;JoinTable(name="CUST_PHONE")&#93;
///       &#91;JoinColumn(AttributeRef="CUST_PHONE",name="CUST_ID", referencedColumnName="ID")&#93;
///       &#91;JoinColumn(AttributeRef="CUST_PHONE",name="PHONE_ID", referencedColumnName="ID", Inverse=true)&#93;
///    )
/// </code></example>
/// 
/// <seealso cref="JoinColumn"/>
/// 
/// 
/// </summary>
[System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property, AllowMultiple=true)] 


public sealed class JoinTable : System.Attribute {

    /// <summary> (Optional) The name of the join table. 
    /// 
    ///  Defaults to the concatenated names of
    /// the two associated primary entity tables, 
    /// separated by an underscore.
    /// </summary>
    public string Name = "";

    /// <summary> (Optional) The catalog of the table. 
    ///  Defaults to the default catalog.
    /// </summary>
    public string Catalog = "";

    /// <summary> (Optional) The schema of the table. 
    ///  Defaults to the default schema for user.
    /// </summary>
    public string Schema = "";

    /// <summary> (Optional) determines that this join table belongs to an AssociationOverride definition.
    /// If populated, this join table overrides a mapping of a relationship.
    /// The joinTable element must be specified if a join table is used in the overriding of the mapping of the relationship.
    /// The joinTable element must not be specified if a foreign key mapping is used in the overriding of the relationship.
    /// </summary>
    public string AssociationOverrideRef = "";
    
}
}