/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Specifies a named native SQL query.
/// <para>
/// Query names are scoped to the persistence unit.
    /// </para>
    /// <para>
/// The <c>NamedNativeQuery</c> annotation can be applied to an 
/// entity or mapped superclass.
    /// </para>
/// 
/// </summary>
[System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple=true)] 

public sealed class NamedNativeQuery : System.Attribute {

    /// <summary> The name used to refer to the query with the <see cref="EntityManager"/>
    /// methods that create query objects.
    /// </summary>
    public string Name;

    /// <summary> The SQL query string.
    /// </summary>
    public string Query;

    /// <summary> Query properties and hints.  (May include vendor-specific query hints.)
    /// </summary>
    public QueryHint[] Hints = {};

    /// <summary> The class of the result.
    /// </summary>
    public System.Type ResultClass = typeof(void);

    /// <summary> The name of a <see cref="SqlResultSetMapping"/>, as defined in metadata.
    /// </summary>
    public string ResultSetMapping = "";
}
}