/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


/// <summary> Specifies the ordering of the elements of a collection valued
/// association or element collection at the point when the association
/// or collection is retrieved.
    /// <para>
///  The syntax of the <c>value</c> ordering element is an 
/// <c>orderby_list</c>, as follows:
/// </para>
/// <example><code>
///    orderby_list::= orderby_item [,orderby_item]*
///    orderby_item::= [property_or_field_name] [ASC | DESC]
/// </code></example>
    /// <para>
///  If <c>ASC</c> or <c>DESC</c> is not specified, 
/// <c>ASC</c> (ascending order) is assumed.
    /// </para><para>
///  If the ordering element is not specified for an entity association,
/// ordering by the primary key of the associated entity is assumed.
    /// </para><para>
///  The property or field name must correspond to that of a 
/// persistent property or field of the associated class or embedded class
/// within it.  
    /// </para><para>
/// The properties or fields used in the ordering must correspond to 
/// columns for which comparison operators are supported.
    /// </para><para>
///  The dot (".") notation is used to refer to an attribute within an
/// embedded attribute.  The value of each identifier used with the dot
/// notation is the name of the respective embedded field or property.
    /// </para><para>
///  The <c>OrderBy</c> annotation may be applied to an element
/// collection. 
    /// </para><para>When <c>OrderBy</c> is applied to an element collection of
/// basic type, the ordering will be by value of the basic objects and
/// the property or field name is not used. 
    /// </para><para>When specifying an ordering
/// over an element collection of embeddable type, the dot notation
/// must be used to specify the attribute or attributes that determine
/// the ordering.  
    /// </para><para>
///  The <c>OrderBy</c> annotation is not used when an order
/// column is specified.
/// </para>
/// 
/// <example><code>
///    Example 1:
///    
///    &#91;Entity&#93; 
///    public class Course {
///       ...
///       &#91;ManyToMany&#93;
///       &#91;OrderBy("lastname ASC")&#93;
///       public List&#060;Student&#062; getStudents() {...};
///       ...
///    }
///    
///    Example 2:
/// 
///    &#91;Entity&#93; 
///    public class Student {
///       ...
///       &#91;ManyToMany(mappedBy="students")&#93;
///       // ordering by primary key is assumed
///       public List&#060;Course&#062; getCourses() {...};
///       ...
///    }
/// 
///    Example 3: 
/// 
///    &#91;Entity&#93; 
///    public class Person {
///         ...
///       &#91;ElementCollection&#93;
///       &#91;OrderBy("zipcode.zip, zipcode.plusFour")&#93;
///       public Set&#060;Address&#062; getResidences() {...};
///       ...
///    }
///  
///    &#91;Embeddable&#93; 
///    public class Address {
///       protected String street;
///       protected String city;
///       protected String state;
///       &#91;Embedded&#93; protected Zipcode zipcode;
///    }
/// 
///    &#91;Embeddable&#93; 
///    public class Zipcode {
///       protected String zip;
///       protected String plusFour;
///    }
/// </code></example>
/// 
/// <seealso cref="OrderColumn"/>
/// 
/// 
/// </summary>
[System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)] 


public sealed class OrderBy : System.Attribute {

   /// <summary>
   /// An <c>orderby_list</c>.  Specified as follows:
   /// 
   /// <example><code>
   ///    orderby_list::= orderby_item [,orderby_item]*
   ///    orderby_item::= [property_or_field_name] [ASC | DESC]
   /// </code></example>
   /// 
   ///  If <c>ASC</c> or <c>DESC</c> is not specified,
   /// <c>ASC</c> (ascending order) is assumed.
   /// 
   ///  If the ordering element is not specified, ordering by
   /// the primary key of the associated entity is assumed.
   /// </summary>
    public string Value = ""; public OrderBy() {} public OrderBy(string value) { Value = value; } 
}
}