/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> Expresses a dependency on a container-managed <see cref="EntityManager"/> and its
/// associated persistence context.
/// 
/// 
/// </summary>

    [System.AttributeUsage(System.AttributeTargets.Class | System.AttributeTargets.Field | System.AttributeTargets.Property, AllowMultiple = true)]

public sealed class PersistenceContext : System.Attribute {

    /// <summary> (Optional) The name by which the entity manager is to be accessed in the 
    /// environment referencing context; not needed when dependency 
    /// injection is used.
    /// </summary>
    public string Name = "";

    /// <summary> (Optional) The name of the persistence unit as defined in the
    /// <c>persistence.xml</c> file. If the <c>unitName</c> element is
    /// specified, the persistence unit for the entity manager that is
    /// accessible in JNDI must have the same name.
    /// </summary>
    public string UnitName = "";

    /// <summary> (Optional) Specifies whether a transaction-scoped persistence context 
    /// or an extended persistence context is to be used.
    /// </summary>
    public PersistenceContextType Type = PersistenceContextType.TRANSACTION;

    /// <summary> (Optional) Properties for the container or persistence
    /// provider.  Vendor specific properties may be included in this
    /// set of properties.  Properties that are not recognized by
    /// a vendor are ignored.  
    /// </summary> 
    public PersistenceProperty[] Properties = {};
}
}