﻿namespace NPersistence.Ext/*javax.jdo.annotations*/
{
    using System;
    using System.Reflection;
    using System.Collections;
    using System.Collections.Generic;

    /// <summary>
    /// Specifies that a unique constraint should be placed on the column or group of columns.
    /// 
    /// <example><code>
    ///    Example 1:
    ///    2 different unique constraints for the 2 columns
    ///    &#91;Unique&#93;
    ///    public String getName() { return name; }
    ///    
    ///    &#91;Unique&#93;
    ///    public String getDescription() { return description; }
    /// 
    ///    Example 2:
    ///    Both columns included in one unique constraint.
    ///    &#91;Unique(Name="uq1")&#93;
    ///    public String getName() { return name; }
    ///    
    ///    &#91;Unique(Name="uq1")&#93;
    ///    public String getDescription() { return description; }
    ///    
    ///    Example 3:
    ///    The Unique annotation is defined at the Entity level
    ///    &#91;Unique(Name="ix1", Members=new String[]{"name", "description"})&#93;
    ///    &#91;Entity&#93;
    ///    public class Person
    ///    ...
    ///    public String getName() { return name; }
    ///    public String getDescription() { return description; }
    /// 
    /// 
    /// </code></example>
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property | AttributeTargets.Class)]
    public sealed class Unique : System.Attribute
    {
        /// <summary>
        /// (Optional) Name of the unique constraint, if not specified defaults to a generated unique constraint name given by the vendor.
        /// Default value:
        /// ""
        /// </summary>
        public String Name = "";

        /// <summary>
        /// Member names that compose this unique constraint.
        /// Relevant only when the Unique annotation is used on a class.
        /// Returns:
        /// member names that compose this unique constraint.
        /// </summary>
        public String[] Members;
    }
}