/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence.spi { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Interface implemented by the persistence provider.
/// Invoked by the <see cref="NPersistence.Persistence"/> class to
/// create an <see cref="NPersistence.EntityManagerFactory"/>.
/// 
/// </summary>
public interface PersistenceProvider {

    /// <summary> Called by <c>Persistence</c> class when an
    /// <c>EntityManagerFactory</c> is to be created.
    /// </summary>
    /// <param name="emName">the name of the persistence unit</param>
    /// <param name="map">  a Map of properties for use by the 
    /// persistence provider. These properties may be used to
    /// override the values of the corresponding elements in 
    /// the <c>persistence.xml</c> file or specify values for 
    /// properties not specified in the <c>persistence.xml</c>
    /// (and may be null if no properties are specified).</param>
    /// <returns> EntityManagerFactory for the persistence unit, 
    /// or null if the provider is not the right provider </returns>
    /// 
    EntityManagerFactory CreateEntityManagerFactory(string emName, Dictionary<object,object> map);

    /// <summary> Called by the container when an <c>EntityManagerFactory</c>
    /// is to be created. 
    /// </summary>
    /// <param name="info">  metadata for use by the persistence provider</param>
    /// <param name="map">a Map of integration-level properties for use 
    /// by the persistence provider (may be null if no properties
    /// are specified).
    /// If a Bean Validation provider is present in the classpath,
    /// the container must pass the <c>ValidatorFactory</c> instance in
    /// the map with the key <c>"NPersistence.validation.factory"</c>.</param>
    /// <returns> EntityManagerFactory for the persistence unit 
    /// specified by the metadata</returns>
    /// 
    EntityManagerFactory CreateContainerEntityManagerFactory(
        PersistenceUnitInfo info, Dictionary<object,object> map);

    /// <summary> Return the utility interface implemented by the persistence
    /// provider.</summary>
    /// <returns> ProviderUtil interface</returns>
    /// 
    /// 
    ProviderUtil GetProviderUtil();
}

}